NebulaFlutterPluginPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • NebulaFlutterPluginPlatform
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bindDeviceByCloud(Map<String, dynamic> cloudConfig, {int timeout = 20000}) Future<bool>
Bind via Cloud (MQTT).
cancelTransaction() Future<bool>
Cancel a running transaction.
connectBluetooth(String identifier, {int timeout = 20000}) Future<bool>
Connect via Bluetooth.
connectCloud({int timeout = 20000}) Future<bool>
Connect via Cloud using saved tokens.
connectTcp(String host, int port, {int timeout = 20000}) Future<bool>
Connect via TCP (WiFi).
connectUsb({int timeout = 20000}) Future<bool>
Connect via USB.
disconnect() Future<void>
Disconnect current connection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage(String packageName, String message) Future<void>
Send a message to a specific package.
setMethodCallHandler(Future handler(String method, dynamic arguments)?) → void
Set callback handler for method calls from native.
startTransaction(String category, Map<String, dynamic> request) Future<Map<String, dynamic>>
Start a transaction.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NebulaFlutterPluginPlatform
getter/setter pair