MethodChannelNebulaFlutterPlugin class
An implementation of NebulaFlutterPluginPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- NebulaFlutterPluginPlatform
- MethodChannelNebulaFlutterPlugin
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bindDeviceByCloud(
Map< String, dynamic> cloudConfig, {int timeout = 20000}) → Future<bool> -
Bind via Cloud (MQTT).
override
-
cancelTransaction(
) → Future< bool> -
Cancel a running transaction.
override
-
connectBluetooth(
String identifier, {int timeout = 20000}) → Future< bool> -
Connect via Bluetooth.
override
-
connectCloud(
{int timeout = 20000}) → Future< bool> -
Connect via Cloud using saved tokens.
override
-
connectTcp(
String host, int port, {int timeout = 20000}) → Future< bool> -
Connect via TCP (WiFi).
override
-
connectUsb(
{int timeout = 20000}) → Future< bool> -
Connect via USB.
override
-
disconnect(
) → Future< void> -
Disconnect current connection.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendMessage(
String packageName, String message) → Future< void> -
Send a message to a specific package.
override
-
setMethodCallHandler(
Future handler(String method, dynamic arguments)?) → void -
Set callback handler for method calls from native.
override
-
startTransaction(
String category, Map< String, dynamic> request) → Future<Map< String, dynamic> > -
Start a transaction.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited